import * as ec2 from '@aws-cdk/aws-ec2';
import * as eks from '@aws-cdk/aws-eks';
import * as iam from '@aws-cdk/aws-iam';
import * as cdk from '@aws-cdk/core';
import * as runner from './runner';
/**
 *
 */
export interface ProviderProps {
    /**
     *
     */
    readonly vpc?: ec2.IVpc;
}
/**
 *
 */
export interface RoleProps {
    /**
     *
     */
    readonly accountId: string;
    /**
     *
     */
    readonly externalId: string;
}
/**
 *
 */
export interface EksClusterOptions {
    /**
     * create serivce account and rbac ClusterRoleBinding for gitlab.
     *
     * @default true
     * @see https://docs.gitlab.com/ee/user/project/clusters/add_remove_clusters.html#add-existing-cluster
     */
    readonly rbac?: boolean;
    /**
     * cluster properties for Amazon EKS cluster.
     */
    readonly clusterOptions: eks.ClusterProps;
}
/**
 *
 */
export interface FargateEksClusterOptions {
    /**
     * create serivce account and rbac ClusterRoleBinding for gitlab.
     *
     * @default true
     * @see https://docs.gitlab.com/ee/user/project/clusters/add_remove_clusters.html#add-existing-cluster
     */
    readonly rbac?: boolean;
    /**
     * cluster properties for Amazon EKS cluster.
     */
    readonly clusterOptions: eks.FargateClusterProps;
}
/**
 * The Provider to create GitLab Integrations with AWS.
 */
export declare class Provider extends cdk.Construct {
    /**
     *
     */
    gitlabEksRole?: iam.IRole;
    /**
     *
     */
    readonly vpc: ec2.IVpc;
    /**
     *
     */
    constructor(scope: cdk.Construct, id: string, props?: ProviderProps);
    /**
     *
     */
    createFargateRunner(executor?: runner.FargateJobExecutor): void;
    /**
     *
     */
    createEksCluster(scope: cdk.Construct, id: string, props: EksClusterOptions): eks.Cluster;
    /**
     *
     */
    createFargateEksCluster(scope: cdk.Construct, id: string, props: FargateEksClusterOptions): eks.Cluster;
    /**
     *
     */
    createSecurityGroup(): ec2.SecurityGroup;
    /**
     *
     */
    createEksServiceRole(): iam.Role;
    /**
     *
     */
    createGitlabManagedEksRole(props: RoleProps): void;
}
